clear all

fmt='real*8';
accuracy='real*8';
Ieee='b';


%---> Parameters

nx=128;
ny=64;
nz=15;
nt=12;
onedegx=nx/72;
onedegy=ny/140;

NyNorth=ny-5;

lati=1*((1:ny)-(ny+1)/2);

time=inf;

%exp=cellstr(['LGM_single_ice/output/present_idiff50']);
%dxc=rdmds(['../../',char(exp(1)),'/DXC']);
%dyc=rdmds(['../../',char(exp(1)),'/DYC']);% constant!

latc=ones(nx,1)*[-90:2.8125:90-2.8125];
dyc=6.37e6*2*pi*2.8125/360*ones(nx,ny);
dxc=6.37e6*2*pi*2.8125/360*ones(nx,ny).*cosd(latc);

%================================================
%=============>   TOPOGRAPHY    <================
%================================================

topo = zeros(nx,ny);
topo(:,:) = -4000. ;

%south
topo(:,1) = 0.;
%north
%topo(:,ny) = 0.;
topo(:,NyNorth:ny) = 0.;
%America  
topo(1 ,23:ny) = 0.;
topo(end ,23:ny) = 0.;
%Antarctic peninsula  
%topo(1 ,2:6) = 0.;
%Scotia Ridge
topo(1 ,2:22) = -3000.;
topo(end ,2:22) = -3000.;

fid = fopen('bathy.bin','r', 'b');
topo2 = fread(fid,[128,64],'single');


mask = topo2;

for j=1:ny
    for i=1:nx
        if mask(i,j) == 0
            mask(i,j) = 0. ; 
        else
            mask(i,j) = 1. ; 
        end
    end
end

% fid=fopen('topog.bin','w','b'); fwrite(fid,topo,'real*4'); fclose(fid);
% 
% figure(1)
% clf
% imagesc(topo); colorbar

%================================================
%==============>      Wind      <================
%================================================

wind  = zeros(nx,ny);
tau0=10; % notice that this is actually peak wind-speed now

for j=1:18
	y=j-1.2*64/140;
	wind(:,j)=1.007*tau0*(sin(3.5*pi*y/(ny-2)));
end
for j=19:27
	y=j-40.8*64/140;
	wind(:,j)=-0.65*tau0*(sin(3.5*pi*y/(ny-2)));
end
for j=28:37
	wind(:,j)=-0.65*tau0;
end
for j=37:46
	y=j-100.2*64/140;
	wind(:,j)=0.65*tau0*(sin(3.5*pi*y/(ny-2)));
end
for j=47:64
	y=j-120*64/140;
	wind(:,j)=0.58*tau0*(cos(3.5*pi*(y)/(ny-2)));
end

for j=21:43
	y=j-70.5*64/140;
	wind(:,j)=wind(:,j)+0.56*tau0*(cos(3*pi*y/(ny+0.5)))^2;
end

% for i=1:nx
%   wind(i,:)=smooth(wind(i,:),5);
% end

wind(:,1)= 0;
wind(:,ny)= 0;

fid=fopen('wind_x.bin','w','b'); fwrite(fid,wind,'real*4'); fclose(fid);

% figure(2)
% clf
% subplot(2,1,1)
% plot(wind(2,:))
% hold on

% meridional (katabatic) wind:
Vmax=2; % peak meridional wind-speed (m/s)

vkata=zeros(nx,ny);
for j=2:7
    for i=1:nx
	  vkata(i,j)=Vmax*sin(pi*i/nx)*(cos(pi*(j-2)/10));
    end
end

% plot(mean(vkata(:,:),1),'r')
% 
% figure(6)
% clf
% imagesc(vkata)
% 
fid=fopen('wind_y.bin','w','b'); fwrite(fid,vkata,'real*4'); fclose(fid);


%=====================================================
%===============>  Air temperature  <=================
%=====================================================


 %T_air = zeros(nx,ny,nt);
 T_air_ave = zeros(nx,ny);
 lats = zeros(51)
 fid2 = fopen('lev_monthly_temp.bin', 'r', 'b');
 T_air = fread(fid2,[128*64, 12],'single');
 T_air = reshape(T_air, [128 64 12]);
 
 for i=1:nx
     for j=1:ny
         T_air_ave(i,j) = mean(T_air(i,j,:));
     end
 end
 T_trans = T_air_ave(65,5:55);
 for i=1:51
     lats(i) = -78.75 + 2.8125*(i-1);
 end
 plot(lats,T_trans);
% theta = ny-3; %width
% seasamp=9;
% 
% for tt=1:nt
%     for i=1:nx
%         for j=2:ny-1
%             y=(j-(ny+1)/2) * 9.0/7.0;
%             T_air(i,j,tt) =(273.15+37*cos(pi*y/theta)-7-seasamp*cos(2*pi*(tt-1)/nt)*sign(y)*abs(y)^1.5/(theta/2)^1.5);
%         end
%     end
% end

 fid = fopen('T_air.bin','w','b'); fwrite(fid,T_air,'real*4'); fclose(fid);
% fid2 = fopen('T_air.bin', 'r','b'); fread(fid2, [128,64,12], 'real*4'); fclose(fid2);

% figure(3)
% clf
%plot(squeeze(T_air(10,2:end-4,1:7))-273.15);
%hold on;plot(squeeze(T_air(10,2:end-4,8:end))-273.15,'--');
% legend({'Jan','Feb/Dec','Mar/Nov','Apr/Oct','May/Sep','Jun/Aug','Jul'},'fontsize',12)
% hold off;

%====================================================================
%===================> Longwave radiative flux <============================
%====================================================================

sigma=5.67e-8;

Qc=sigma*(T_air + 273.15).^4;

fid=fopen('LW_down.bin','w','b'); fwrite(fid,Qc,'real*4'); fclose(fid);

% figure(4)
% clf
% imagesc(mean(Qc,3));
% hold off;



%=====================================================
%==================>    E - P    <====================
%=====================================================
empconst=0.5/3.1536e7; 

theta1 = ny-7;

emp = zeros(nx,ny);

for i=1:nx
 for j=2:ny-1
    y=(j-(ny+1)/2)*9.0/7.0;
	emp(i,j) = -empconst*mask(i,j)*(cos(2*pi*abs(2*y/theta1)^0.7));
    %if y <0
      emp(i,j) =emp(i,j) + empconst*(0.5*y-abs(y))/ny;
    %end
 end
end

emp=emp-mean(mean(emp.*dxc.*mask))/mean(mean(dxc.*mask));
emp=emp.*mask;

emp=repmat(emp,[1,1,nt]);

%=====================================================
%===============>    Evaporation    <=================
%=====================================================

evap=0.0*emp;
evap(emp>0)=emp(emp>0);

fid=fopen('evap.bin','w','b'); fwrite(fid,evap,'real*4'); fclose(fid);

%=====================================================
%===============>   Precipitation   <=================
%=====================================================

precip=0.0*emp;
precip(emp<0)=-emp(emp<0);

snowprecip=0*precip;
snowprecip(T_air<273.15)=precip(T_air<273.15);

fid=fopen('precip.bin','w','b'); fwrite(fid,precip,'real*4'); fclose(fid);
fid=fopen('snowprecip.bin','w','b'); fwrite(fid,snowprecip,'real*4'); fclose(fid);




% figure(5)
% clf
% subplot(3,1,1)
% plot(lati([2,end-1]),[0,0],'--k');hold on
% plot(lati(2:NyNorth-1),emp(10,2:NyNorth-1,6));hold on;
% subplot(3,1,2)
% plot(lati(2:NyNorth-1),precip(10,2:NyNorth-1,6));hold on;
% plot(lati(2:NyNorth-1),snowprecip(10,2:NyNorth-1,6));
% subplot(3,1,3)
% plot(lati(2:NyNorth-1),evap(10,2:NyNorth-1,6));

